==> dde-launchpad_1.0.6.tar.xz: BUILD/translations/dde-launchpad_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Vastmaken aan bovenkant</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Verplaatsen naar bovenkant</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Verwijderen uit favorieten</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Toevoegen aan favorieten</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Op bureaublad plaatsen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Verwijderen van bureaublad</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Losmaken van dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Vastmaken aan dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Automatisch opstarten</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Niet automatisch opstarten</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Proxy gebruiken</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Niet aanpassen aan beeldgrootte</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Deïnstalleren</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="103"/>
        <source>Full-screen Mode</source>
        <translation>Schermvullende weergave</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Installeren</translation>
    </message>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Veelgebruikt</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="152"/>
        <source>Window Mode</source>
        <translation>Vensterweergave</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Starter tonen (standaard verborgen)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Starter tonen/verbergen</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Muziek</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Video&apos;s</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Grafisch</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation>Spellen</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Kantoor</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Lezen</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Ontwikkeling</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Systeem</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Overig</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="411"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Weet je zeker dat je ‘%1’ wilt deïnstalleren?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="423"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="437"/>
        <source>Confirm</source>
        <translation>Oké</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Onlangs geïnstalleerd</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Alle programma&apos;s</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="545"/>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Niet sorteren</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Sorteren op categorie</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Sorteren op naam</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Sorteermodus</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Documenten</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Instellingencentrum</translation>
    </message>
</context>
</TS>

==> dde-launchpad_2.0.4.tar.xz: BUILD/translations/dde-launchpad_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Vastmaken aan bovenkant</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Verplaatsen naar bovenkant</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Verwijderen uit favorieten</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Toevoegen aan favorieten</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Op bureaublad plaatsen</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Verwijderen van bureaublad</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Losmaken van dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Vastmaken aan dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Automatisch opstarten</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Niet automatisch opstarten</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Proxy gebruiken</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Niet aanpassen aan beeldgrootte</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Deïnstalleren</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="33"/>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="62"/>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="109"/>
        <source>Full-screen Mode</source>
        <translation>Schermvullende weergave</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Installeren</translation>
    </message>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Veelgebruikt</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="163"/>
        <source>Window Mode</source>
        <translation>Vensterweergave</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="21"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Starter tonen (standaard verborgen)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="22"/>
        <source>Toggle launcher visibility</source>
        <translation>Starter tonen/verbergen</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Muziek</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Video&apos;s</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Grafisch</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Games</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Kantoor</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Lezen</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Ontwikkeling</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Systeem</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Overig</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="400"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Weet je zeker dat je ‘%1’ wilt deïnstalleren?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="412"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="426"/>
        <source>Confirm</source>
        <translation>Oké</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Onlangs geïnstalleerd</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Alle programma&apos;s</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <location filename="../qml/FullscreenFrame.qml" line="556"/>
        <source>No search results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Niet sorteren</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Sorteren op categorie</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Sorteren op naam</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Sorteermodus</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Documenten</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Instellingencentrum</translation>
    </message>
</context>
</TS>
